/*
 @C:\Web_635\Sql\End_Conv\SQLServer\3966_PEDFUNS_Busca_Preco_PED.SQL

 Descrio:
 Funo para retornar o preo base vigente

 Parmetros

 @P_CDFILIAL    - Cdigo da filial
 @P_CDARVPROD   - Cdigo de rvore do produto(CDARVPROD)
 @P_CDCLIENTE   - Cdigo do cliente do pedido
 @P_CDPRECOBASE - Cdigo do preo base do pedido
 @P_DTENTPED    - Data de Entrega do pedido
 P2_CDMODPGTO   - Cdigo da modalidade de pagamento do pedido

 RAISERROR('', 16,1);
*/

IF EXISTS (SELECT *
             FROM SYSOBJECTS O, SYSUSERS U
            WHERE O.NAME = 'BUSCA_PRECO_PED'
              AND TYPE = 'FN'
              AND U.UID = O.UID
              AND U.NAME = USER)

DROP FUNCTION BUSCA_PRECO_PED
GO

CREATE FUNCTION BUSCA_PRECO_PED(
   @P_CDFILIAL     VARCHAR(4),
   @P_CDARVPROD    VARCHAR(10),
   @P_CDCLIENTE    VARCHAR(21),
   @P_CDPRECOBASE  VARCHAR(02),
   @P_DTENTPED     DATE,
   @P_CDMODPGTO    VARCHAR(05)) RETURNS NUMERIC(10,5)
AS
BEGIN
   DECLARE @V_VRTABPRECO   DOUBLE PRECISION;
   DECLARE @V_VRITEPREBASE DOUBLE PRECISION;
   DECLARE @V_VRPEADPBASE  DOUBLE PRECISION;

   DECLARE @V_RESULT       DOUBLE PRECISION;


   --tabela de preco por cliente
   SELECT @V_VRITEPREBASE = ISNULL(MAX(T.VRPRECOPROD), 0)
     FROM TABPRECLIE T,PRODUTO P
    WHERE (P.CDARVPROD = @P_CDARVPROD)
      AND (P.CDPRODUTO = T.CDPRODUTO)
      AND (T.CDCLIENTE = @P_CDCLIENTE)
      AND (
           ( (GETDATE() BETWEEN ISNULL(T.DTVALINI,GETDATE()) AND ISNULL(T.DTVALFIN,GETDATE()))OR
             ((GETDATE() >= ISNULL(T.DTVALINI,GETDATE()))AND(T.DTVALFIN IS NULL))
           )
          )
      AND T.VRPRECOPROD > 0;

   IF NOT(@V_VRITEPREBASE > 0) BEGIN
      --tabela promocional por grupo de clientes e produto
      SELECT @V_VRITEPREBASE = ISNULL(MAX(VRPROMOPRODCLIE), 0)
        FROM PROMOPRODCLIE PC, PRODUTO P, CLIENTE C
       WHERE (P.CDARVPROD   = @P_CDARVPROD )
         AND (CHARINDEX(TRIM(REPLACE(PC.CDARVGRUPPROD, '.', '')), P.CDARVPROD) = 1)
         AND (C.CDCLIENTE = @P_CDCLIENTE)
         AND (CHARINDEX(TRIM(REPLACE(PC.NRINSGRUPCLIE, '.','')), C.NRINSJURCLIE) = 1)
         AND (
              ( (GETDATE() BETWEEN ISNULL(PC.DTPROMOINICIAL,GETDATE()) AND ISNULL(PC.DTPROMOFINAL,GETDATE()))OR
                ((GETDATE() >= ISNULL(PC.DTPROMOINICIAL,GETDATE()))AND(PC.DTPROMOFINAL IS NULL))
               )
              )
         AND VRPROMOPRODCLIE > 0;

      IF NOT(@V_VRITEPREBASE > 0) BEGIN
         --promocao vingente na tabela de preco

         SELECT @V_VRITEPREBASE = CASE MAX(IDSTATUSPROMO) WHEN 'AT' THEN ISNULL(MAX(VRTOTALPROMO),0) ELSE ISNULL(MAX(VRITEPREBASE),0) END
           FROM ITEMPREBASE I, PRODUTO P,PROMOPRBASE PP
          WHERE (I.CDPRECOBASE     = @P_CDPRECOBASE)
            AND (P.CDARVPROD       = @P_CDARVPROD  )
            AND (I.CDPRODUTO       = P.CDPRODUTO   )
            AND (PP.CDPRECOBASE    = I.CDPRECOBASE )
            AND (PP.CDPRODUTO      = I.CDPRODUTO   )
            AND (PP.DTINIVALIPB    = I.DTINIVALIPB )
            AND (((PP.DTINIPROMO IS NULL)AND(PP.DTFINPROMO IS NULL))OR(CONVERT(CHAR,GETDATE(),103) BETWEEN CONVERT(CHAR,PP.DTINIPROMO,103) AND CONVERT(CHAR,PP.DTFINPROMO,103)))
            AND ((PP.IDDIASPROMO IS NULL)OR(DATEPART(W,GETDATE())= PP.IDDIASPROMO)OR(PP.IDDIASPROMO = '8'))
            AND (I.VRITEPREBASE > 0);

         IF NOT(@V_VRITEPREBASE > 0) BEGIN
        -- RAISE_APPLICATION_ERROR(-20405, 'PT1', TRUE);
            --tabela de preco
            SELECT @V_VRITEPREBASE = ISNULL(MAX(I.VRITEPREBASE), 0)
              FROM ITEMPREBASE I, PRODUTO P
             WHERE (I.CDPRECOBASE     = @P_CDPRECOBASE)
               AND (P.CDARVPROD       = @P_CDARVPROD  )
               AND (I.CDPRODUTO       = P.CDPRODUTO   )
               AND ((CONVERT(CHAR,@P_DTENTPED,103) BETWEEN I.DTINIVALIPB AND I.DTFIMVALIPB) OR
                    (I.DTINIVALIPB <= CONVERT(CHAR,@P_DTENTPED,103) AND I.DTFIMVALIPB IS NULL))
               AND (I.VRITEPREBASE > 0);
         END;
      END;
   END;

   SET @V_VRTABPRECO = @V_VRITEPREBASE;


   SELECT @V_VRPEADPBASE = ISNULL(MAX(VRPEADPBASE),0)
     FROM PRECOUTI
    WHERE ((CDFILIAL   = @P_CDFILIAL   ) OR (CDFILIAL IS NULL))
      AND (CDMODPGTO   = @P_CDMODPGTO  )
      AND (CDPRECOBASE = @P_CDPRECOBASE);

   SET @V_RESULT = ROUND((@V_VRTABPRECO + ((@V_VRPEADPBASE) * (@V_VRTABPRECO)) / 100),2);

   RETURN(@V_RESULT);
END
GO

-- VERSAO --
EXEC ATUVEROBJ 'BUSCA_PRECO_PED','6.35.020';
GO
